spannertools.TieSpanner
=======================

.. abjad-lineage:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner

.. autoclass:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.append
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.append_left
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.attach
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.components
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.detach
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.direction
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.extend
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.extend_left
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.fracture
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.fuse
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.get_duration
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.get_timespan
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.index
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.leaves
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.override
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.pop
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.pop_left
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.set
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__call__
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__contains__
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__copy__
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__eq__
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__getitem__
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__len__
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__lt__
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__ne__
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__repr__

Bases
-----

- :py:class:`spannertools.DirectedSpanner <abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner>`

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.set
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner.__repr__
   :noindex:
